@@ -45,8 +45,8 @@
 #' * `file`:  Path to the file to add.
 #' * `url`: URL attribute. This is used to update the file, if requested.
 #' * `sha256`: SHA256 hash of the file.
-#' * `on_progress`: Callback to create progress bard. Passed to
-#'   [http_get()].
+#' * `on_progress`: Callback to create progress bar. Passed to internal
+#'   function `http_get()`.
 #' * `target`: Path to copy the (first) to hit to.
 #' * `urls`: Character vector or URLs to try to download the file from.
 #'
@@ -109,7 +109,7 @@ package_cache <- R6Class(
   "package_cache",
   public = list(
     initialize = function(path = NULL) {
-      path <- path %||% get_user_cache_dir()$root
+      path <- path %||% get_user_cache_dir()$pkg
       assert_that(is_path(path))
       private$path <- path
       create_empty_db_file_if_needed(path)
